@@ -15,8 +15,8 @@
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
 use crate::{
-    impl_additive_ops_from_ref,
-    impl_multiplicative_ops_from_ref,
+    impl_add_sub_from_field_ref,
+    impl_mul_div_from_field_ref,
     FftField,
     Field,
     FieldError,
@@ -31,8 +31,9 @@ use crate::{
 };
 use snarkvm_utilities::{
     biginteger::{arithmetic as fa, BigInteger as _BigInteger, BigInteger384 as BigInteger},
-    bytes::{FromBytes, ToBytes},
     serialize::CanonicalDeserialize,
+    FromBytes,
+    ToBytes,
 };
 
 use std::{
@@ -368,7 +369,7 @@ impl<P: Fp384Parameters> PrimeField for Fp384<P> {
     }
 
     #[inline]
-    fn into_repr(&self) -> BigInteger {
+    fn to_repr(&self) -> BigInteger {
         let mut r = *self;
         r.mont_reduce(
             (self.0).0[0],
@@ -388,13 +389,13 @@ impl<P: Fp384Parameters> PrimeField for Fp384<P> {
     }
 
     #[inline]
-    fn from_repr_raw(r: BigInteger) -> Self {
+    fn from_repr_unchecked(r: BigInteger) -> Self {
         let r = Fp384(r, PhantomData);
         if r.is_valid() { r } else { Self::zero() }
     }
 
     #[inline]
-    fn into_repr_raw(&self) -> BigInteger {
+    fn to_repr_unchecked(&self) -> BigInteger {
         self.0
     }
 }
@@ -450,7 +451,7 @@ impl<P: Fp384Parameters> SquareRootField for Fp384<P> {
 impl<P: Fp384Parameters> Ord for Fp384<P> {
     #[inline(always)]
     fn cmp(&self, other: &Self) -> Ordering {
-        self.into_repr().cmp(&other.into_repr())
+        self.to_repr().cmp(&other.to_repr())
     }
 }
 
@@ -461,28 +462,28 @@ impl<P: Fp384Parameters> PartialOrd for Fp384<P> {
     }
 }
 
-impl_prime_field_from_int!(Fp384, u128, Fp384Parameters);
-impl_prime_field_from_int!(Fp384, u64, Fp384Parameters);
-impl_prime_field_from_int!(Fp384, u32, Fp384Parameters);
-impl_prime_field_from_int!(Fp384, u16, Fp384Parameters);
-impl_prime_field_from_int!(Fp384, u8, Fp384Parameters);
+impl_primefield_from_int!(Fp384, u128, Fp384Parameters);
+impl_primefield_from_int!(Fp384, u64, Fp384Parameters);
+impl_primefield_from_int!(Fp384, u32, Fp384Parameters);
+impl_primefield_from_int!(Fp384, u16, Fp384Parameters);
+impl_primefield_from_int!(Fp384, u8, Fp384Parameters);
 
-impl_prime_field_standard_sample!(Fp384, Fp384Parameters);
+impl_primefield_standard_sample!(Fp384, Fp384Parameters);
 
-impl_additive_ops_from_ref!(Fp384, Fp384Parameters);
-impl_multiplicative_ops_from_ref!(Fp384, Fp384Parameters);
+impl_add_sub_from_field_ref!(Fp384, Fp384Parameters);
+impl_mul_div_from_field_ref!(Fp384, Fp384Parameters);
 
 impl<P: Fp384Parameters> ToBytes for Fp384<P> {
     #[inline]
-    fn write<W: Write>(&self, writer: W) -> IoResult<()> {
-        self.into_repr().write(writer)
+    fn write_le<W: Write>(&self, writer: W) -> IoResult<()> {
+        self.to_repr().write_le(writer)
     }
 }
 
 impl<P: Fp384Parameters> FromBytes for Fp384<P> {
     #[inline]
-    fn read<R: Read>(reader: R) -> IoResult<Self> {
-        BigInteger::read(reader).and_then(|b| match Self::from_repr(b) {
+    fn read_le<R: Read>(reader: R) -> IoResult<Self> {
+        BigInteger::read_le(reader).and_then(|b| match Self::from_repr(b) {
             Some(f) => Ok(f),
             None => Err(FieldError::InvalidFieldElement.into()),
         })
@@ -543,14 +544,14 @@ impl<P: Fp384Parameters> FromStr for Fp384<P> {
 impl<P: Fp384Parameters> Debug for Fp384<P> {
     #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        write!(f, "Fp384({})", self.into_repr())
+        write!(f, "Fp384({})", self.to_repr())
     }
 }
 
 impl<P: Fp384Parameters> Display for Fp384<P> {
     #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        write!(f, "{}", self.into_repr())
+        write!(f, "{}", self.to_repr())
     }
 }
 
@@ -704,7 +705,7 @@ impl<P: Fp384Parameters + PoseidonMDSParameters> PoseidonMDSField for Fp384<P> {
         for row in P::POSEIDON_MDS.iter() {
             mds.push(
                 row.iter()
-                    .map(|b| Self::from_repr_raw(*b))
+                    .map(|b| Self::from_repr_unchecked(*b))
                     .collect::<Vec<Self>>()
                     .to_vec(),
             );
