@@ -17,7 +17,6 @@
 use crate::{One, Zero};
 use snarkvm_utilities::{
     bititerator::BitIteratorBE,
-    bytes::{FromBytes, ToBytes},
     rand::UniformRand,
     serialize::{
         CanonicalDeserialize,
@@ -25,7 +24,11 @@ use snarkvm_utilities::{
         CanonicalSerialize,
         CanonicalSerializeWithFlags,
         ConstantSerializedSize,
+        EmptyFlags,
+        Flags,
     },
+    FromBytes,
+    ToBytes,
 };
 
 use std::{
@@ -146,12 +149,12 @@ pub trait Field:
     /// otherwise returns None. This function is primarily intended for sampling
     /// random field elements from a hash-function or RNG output.
     fn from_random_bytes(bytes: &[u8]) -> Option<Self> {
-        Self::from_random_bytes_with_flags(bytes).map(|f| f.0)
+        Self::from_random_bytes_with_flags::<EmptyFlags>(bytes).map(|f| f.0)
     }
 
     /// Returns a field element with an extra sign bit used for group parsing if
     /// the set of bytes forms a valid field element, otherwise returns
     /// None. This function is primarily intended for sampling
     /// random field elements from a hash-function or RNG output.
-    fn from_random_bytes_with_flags(bytes: &[u8]) -> Option<(Self, u8)>;
+    fn from_random_bytes_with_flags<F: Flags>(bytes: &[u8]) -> Option<(Self, F)>;
 }
